@@ -707,11 +707,17 @@ class Session(Fixture):
         self.local.changed = True
         self.local.data[key] = value
 
+    def __contains__(self, other):
+        return other in self.get_data()
+
     def keys(self):
         return self.get_data().keys()
 
+    def items(self):
+        return self.get_data().items()
+
     def __iter__(self):
-        yield from self.get_data().items()
+        yield from self.get_data().keys()
 
     def clear(self):
         """Produces a brand-new session."""
@@ -788,7 +794,8 @@ def URL(
         if static_version:
             broken_parts.insert(1, "_" + static_version)
 
-    url = prefix + "/".join(map(urllib.parse.quote, broken_parts))
+    url_prefix = os.environ.get("PY4WEB_URL_PREFIX", "")
+    url = url_prefix + prefix + "/".join(map(urllib.parse.quote, broken_parts))
     # Signs the URL if required.  Copy vars into urlvars not to modify it.
     urlvars = dict(vars) if vars else {}
     if signer:
@@ -1356,8 +1363,9 @@ class Reloader:
 
     @staticmethod
     def register_route(app_name, rule, kwargs, func):
+        url_prefix = os.environ.get("PY4WEB_URL_PREFIX", "")
         dec_func = action.catch_errors(app_name, func)
-        bottle.route(rule, **kwargs)(dec_func)
+        bottle.route(url_prefix + rule, **kwargs)(dec_func)
         filename = module2filename(func.__module__)
         methods = kwargs.get("method", ["GET"])
         if isinstance(methods, str):
@@ -1963,6 +1971,13 @@ def new_app(apps_folder, app_name, yes, scaffold_zip):
     help="Debug switch",
     show_default=True,
 )
+@click.option(
+    "-U",
+    "--url_prefix",
+    default="",
+    help="Prefix to add to all URLs in and out",
+    show_default=True,
+)
 def run(**kwargs):
     """Run all the applications on apps_folder"""
     install_args(kwargs)
