@@ -11,12 +11,12 @@ Provides an authenticate function that will allow the caller to authenticate
 a user against the Pluggable Authentication Modules (PAM) on the system.
 Implemented using ctypes, so no compilation is necessary.
 """
-__all__ = ['authenticate']
+__all__ = ["authenticate"]
 
-from ctypes import CDLL, POINTER, Structure, CFUNCTYPE, cast, byref, sizeof
-from ctypes import c_void_p, c_uint, c_char_p, c_char, c_int
-from ctypes.util import find_library
 import sys
+from ctypes import (CDLL, CFUNCTYPE, POINTER, Structure, byref, c_char,
+                    c_char_p, c_int, c_uint, c_void_p, cast, sizeof)
+from ctypes.util import find_library
 
 libpam = CDLL(find_library("pam"))
 libc = CDLL(find_library("c"))
@@ -40,9 +40,8 @@ PAM_REINITIALIZE_CRED = 0x0008  # This constant is libpam-specific.
 
 class PamHandle(Structure):
     """wrapper class for pam_handle_t"""
-    _fields_ = [
-        ("handle", c_void_p)
-    ]
+
+    _fields_ = [("handle", c_void_p)]
 
     def __init__(self):
         Structure.__init__(self)
@@ -51,6 +50,7 @@ class PamHandle(Structure):
 
 class PamMessage(Structure):
     """wrapper class for pam_message structure"""
+
     _fields_ = [
         ("msg_style", c_int),
         ("msg", c_char_p),
@@ -62,6 +62,7 @@ class PamMessage(Structure):
 
 class PamResponse(Structure):
     """wrapper class for pam_response structure"""
+
     _fields_ = [
         ("resp", c_char_p),
         ("resp_retcode", c_int),
@@ -70,21 +71,21 @@ class PamResponse(Structure):
     def __repr__(self):
         return "<PamResponse %i '%s'>" % (self.resp_retcode, self.resp)
 
-conv_func = CFUNCTYPE(c_int, c_int, POINTER(POINTER(PamMessage)),
-                      POINTER(POINTER(PamResponse)), c_void_p)
+
+conv_func = CFUNCTYPE(
+    c_int, c_int, POINTER(POINTER(PamMessage)), POINTER(POINTER(PamResponse)), c_void_p
+)
 
 
 class PamConv(Structure):
     """wrapper class for pam_conv structure"""
-    _fields_ = [
-        ("conv", conv_func),
-        ("appdata_ptr", c_void_p)
-    ]
+
+    _fields_ = [("conv", conv_func), ("appdata_ptr", c_void_p)]
+
 
 pam_start = libpam.pam_start
 pam_start.restype = c_int
-pam_start.argtypes = [c_char_p, c_char_p, POINTER(PamConv),
-                      POINTER(PamHandle)]
+pam_start.argtypes = [c_char_p, c_char_p, POINTER(PamConv), POINTER(PamHandle)]
 
 pam_authenticate = libpam.pam_authenticate
 pam_authenticate.restype = c_int
@@ -99,8 +100,7 @@ pam_end.restype = c_int
 pam_end.argtypes = [PamHandle, c_int]
 
 
-def authenticate(username, password, service='login', encoding='utf-8',
-                 resetcred=True):
+def authenticate(username, password, service="login", encoding="utf-8", resetcred=True):
     """Returns True if the given username and password authenticate for the
     given service.  Returns False otherwise.
     ``username``: the username to authenticate
@@ -148,7 +148,7 @@ def authenticate(username, password, service='login', encoding='utf-8',
         return False
 
     retval = pam_authenticate(handle, 0)
-    auth_success = (retval == 0)
+    auth_success = retval == 0
 
     # Re-initialize credentials (for Kerberos users, etc)
     # Don't check return code of pam_setcred(), it shouldn't matter
@@ -160,7 +160,8 @@ def authenticate(username, password, service='login', encoding='utf-8',
 
     return auth_success
 
+
 if __name__ == "__main__":
     import getpass
+
     print(authenticate(getpass.getuser(), getpass.getpass()))
-    
\ No newline at end of file
