@@ -275,6 +275,108 @@ class GridClassStyleBulma(GridClassStyle):
     }
 
 
+class GridClassStyleBootstrap5(GridClassStyle):
+    """The Grid style for Bootstrap 5"""
+
+    classes = {
+        "grid-wrapper": "grid-wrapper",
+        "grid-header": "grid-header clearfix pb-2",
+        "grid-new-button": "grid-new-button btn btn-outline-primary",
+        "grid-search": "grid-search float-end pb-2",
+        "grid-table-wrapper": "grid-table-wrapper table-responsive",
+        "grid-table": "grid-table table table-striped table-hover table-bordered clearfix",
+        "grid-sorter-icon-up": "grid-sort-icon-up fas fa-sort-up float-end",
+        "grid-sorter-icon-down": "grid-sort-icon-down fas fa-sort-down float-end",
+        "grid-thead": "",
+        "grid-tr": "",
+        "grid-th": "small",
+        "grid-td": "small",
+        "grid-td-buttons": "",
+        "grid-button": "grid-button btn btn-sm btn-outline-secondary",
+        "grid-details-button": "grid-details-button btn btn-sm btn-outline-secondary",
+        "grid-edit-button": "grid-edit-button btn btn-sm btn-outline-secondary",
+        "grid-delete-button": "grid-delete-button btn btn-sm btn-outline-secondary",
+        "grid-search-button": "grid-search-button btn btn-outline-info",
+        "grid-clear-button": "grid-clear-button btn btn-outline-info",
+        "grid-footer": "grid-footer pb-8",
+        "grid-info": "grid-info float-start",
+        "grid-pagination": "grid-pagination float-end",
+        "grid-pagination-button": "grid-pagination-button btn btn-sm btn-outline-primary",
+        "grid-pagination-button-current": "grid-pagination-button-current btn btn-primary btn-sm",
+        "grid-cell-type-string": "grid-cell-type-string",
+        "grid-cell-type-text": "grid-cell-type-text",
+        "grid-cell-type-boolean": "grid-cell-type-boolean text-center",
+        "grid-cell-type-float": "grid-cell-type-float",
+        "grid-cell-type-decimal": "grid-cell-type-decimal",
+        "grid-cell-type-int": "grid-cell-type-int",
+        "grid-cell-type-date": "grid-cell-type-date",
+        "grid-cell-type-time": "grid-cell-type-time",
+        "grid-cell-type-datetime": "grid-cell-type-datetime",
+        "grid-cell-type-upload": "grid-cell-type-upload",
+        "grid-cell-type-list": "grid-cell-type-list",
+        "grid-cell-type-id": "grid-cell-type-id text-center",
+        # specific for custom form
+        "grid-search-form": "grid-search-form float-end pb-2",
+        "grid-search-form-table": "grid-search-form-table",
+        "grid-search-form-tr": "grid-search-form-tr",
+        "grid-search-form-td": "grid-search-form-td pr-1",
+        "grid-search-form-input": "grid-search-form-input form-control",
+        "grid-search-form-select": "grid-search-form-input control select",
+        "grid-search-boolean": "grid-search-boolean",
+        "grid-header-element": "grid-header-element btn btn-sm",
+        "grid-footer-element": "grid-footer-element btn btn-sm",
+    }
+
+    styles = {
+        "grid-wrapper": "",
+        "grid-header": "",
+        "grid-new-button": "",
+        "grid-search": "",
+        "grid-table-wrapper": "",
+        "grid-table": "",
+        "grid-sorter-icon-up": "",
+        "grid-sorter-icon-down": "",
+        "grid-thead": "",
+        "grid-tr": "",
+        "grid-th": "text-align: center; text-transform: uppercase; vertical-align: bottom; text-decoration: none;",
+        "grid-td": "",
+        "grid-td-buttons": "white-space: nowrap; width: 1%;",
+        "grid-button": "",
+        "grid-details-button": "border-radius: 0 !important;",
+        "grid-edit-button": "border-radius: 0 !important;",
+        "grid-delete-button": "border-radius: 0 !important;",
+        "grid-search-button": "border-radius: 0 !important;",
+        "grid-clear-button": "border-radius: 0 !important;",
+        "grid-footer": "padding-top: .5em; padding-bottom: 2em;",
+        "grid-info": "",
+        "grid-pagination": "",
+        "grid-pagination-button": "margin-left: .25em; border-radius: 0 !important;",
+        "grid-pagination-button-current": "margin-left: .25em; border-radius: 0 !important;",
+        "grid-cell-type-string": "vertical-align: top; text-overflow: ellipsis;",
+        "grid-cell-type-text": "vertical-align: top; text-overflow: ellipsis;",
+        "grid-cell-type-boolean": "vertical-align: top; text-align: center",
+        "grid-cell-type-float": "vertical-align: top; text-align: right",
+        "grid-cell-type-decimal": "vertical-align: top; text-align: right",
+        "grid-cell-type-int": "vertical-align: top; text-align: center;",
+        "grid-cell-type-date": "vertical-align: top; text-align: center;",
+        "grid-cell-type-time": "vertical-align: top; text-align: center;",
+        "grid-cell-type-datetime": "vertical-align: top; text-align: center;",
+        "grid-cell-type-upload": "vertical-align: top; text-align: center;",
+        "grid-cell-type-list": "vertical-align: top; text-align: left;",
+        "grid-cell-type-id": "",
+        # specific for custom form
+        "grid-search-form": "",
+        "grid-search-form-table": "",
+        "grid-search-form-tr": "",
+        "grid-search-form-td": "",
+        "grid-search-form-input": "",
+        "grid-search-form-select": "",
+        "grid-search-boolean": "padding-top: .5rem;",
+        "grid-header-element": "",
+        "grid-footer-element": "",
+    }
+
+
 class Column:
     """class used to represent a column in a grid"""
 
@@ -663,9 +765,9 @@ class Grid:
         elif self.action == "delete" and self.is_deletable(record):
             db(db[self.tablename].id == self.record_id).delete()
 
-            rereffer = parse_referer(request)
+            referrer = parse_referer(request)
             url = self.endpoint + "/select"
-            if referred and referrer.query:
+            if referrer and referrer.query:
                 url += "?%s" % referrer.query
             redirect(url)
 
